<?php

if (!defined('ABSPATH')) {
    exit();
}

if (!class_exists('App_Expert_Categories_Images')) {
    class App_Expert_Categories_Images {
        
        private $aeci_placeholder;
        
        public function __construct() {
            $this->aeci_placeholder = APP_EXPERT_URL . 'assets/images/placeholder.png';
            
            add_action('admin_init', [$this, 'AppExpertAdminInit']);

            // save our taxonomy image while edit or create term
            add_action('edit_term', [$this, 'AppExpertSaveTaxonomyImage']);
            add_action('create_term', [$this, 'AppExpertSaveTaxonomyImage']);
        }
        
        public function AppExpertAdminInit() {
            $ae_taxonomies = get_taxonomies();
            if (is_array($ae_taxonomies)) {
                $aeci_options = get_option('aeci_options');

                if (!is_array($aeci_options))
                    $aeci_options = array();

                if (empty($aeci_options['included_taxonomies']))
                    $aeci_options['included_taxonomies'] = array();

                foreach ($ae_taxonomies as $ae_taxonomy) {
                    if (in_array($ae_taxonomy, $aeci_options['included_taxonomies'])) {
                        add_action($ae_taxonomy.'_add_form_fields', [$this, 'AppExpertAddTexonomyField']);
                        add_action($ae_taxonomy.'_edit_form_fields', [$this, 'AppExpertEditTexonomyField']);
                        add_filter('manage_edit-'.$ae_taxonomy.'_columns', [$this, 'AppExpertTaxonomyColumns']);
                        add_filter('manage_'.$ae_taxonomy.'_custom_column', [$this, 'AppExpertTaxonomyColumn'], 10, 3 );

                        // If tax is deleted
                        add_action("delete_{$ae_taxonomy}", function($tt_id) {
                            delete_option('ae_taxonomy_image'.$tt_id);
                        });
                    }
                }
            }

            // Register styles and scripts
            if ( strpos( $_SERVER['SCRIPT_NAME'], 'edit-tags.php' ) > 0 || strpos( $_SERVER['SCRIPT_NAME'], 'term.php' ) > 0 ) {
                add_action('admin_enqueue_scripts', [$this, 'AppExpertAdminEnqueue']);
                add_action('quick_edit_custom_box', [$this, 'AppExpertQuickEditCustomBox'], 10, 3);
            }
        }
        
        public function AppExpertAdminEnqueue() {
            wp_enqueue_style('app-expert-categories-images-styles', APP_EXPERT_URL . 'assets/css/aeci-styles.css');
            wp_enqueue_script('app-expert-categories-images-scripts', APP_EXPERT_URL . 'assets/js/aeci-scripts.js');

            $aeci_js_config = [
                'wordpress_ver' => get_bloginfo("version"),
                'placeholder' => $this->aeci_placeholder
            ];
            wp_localize_script('app-expert-categories-images-scripts', 'aeci_config', $aeci_js_config);
        }

        // add image field in add form
        public function AppExpertAddTexonomyField() {
            if (get_bloginfo('version') >= 3.5){
                wp_enqueue_media();
            } else {
                wp_enqueue_style('thickbox');
                wp_enqueue_script('thickbox');
            }

            echo '<div class="form-field">
                <label for="aeci_taxonomy_image">' . __('Image', 'app-expert') . '</label>
                <input type="text" name="aeci_taxonomy_image" id="aeci_taxonomy_image" value="" />
                <br/>
                <button class="ae_upload_image_button button">' . __('Upload/Add image', 'app-expert') . '</button>
            </div>';
        }

        // add image field in edit form
        public function AppExpertEditTexonomyField($taxonomy) {
            if (get_bloginfo('version') >= 3.5){
                wp_enqueue_media();
            } else {
                wp_enqueue_style('thickbox');
                wp_enqueue_script('thickbox');
            }

            if ($this->AppExpertTaxonomyImageUrl( $taxonomy->term_id, NULL, TRUE ) == $this->aeci_placeholder) 
                $image_url = "";
            else
                $image_url = $this->AppExpertTaxonomyImageUrl( $taxonomy->term_id, NULL, TRUE );
            echo '<tr class="form-field">
                <th scope="row" valign="top"><label for="aeci_taxonomy_image">' . __('Image', 'app-expert') . '</label></th>
                <td><img class="aeci-taxonomy-image" src="' . $this->AppExpertTaxonomyImageUrl( $taxonomy->term_id, 'medium', TRUE ) . '"/><br/><input type="text" name="aeci_taxonomy_image" id="aeci_taxonomy_image" value="'.$image_url.'" /><br />
                <button class="ae_upload_image_button button">' . __('Upload/Add image', 'app-expert') . '</button>
                <button class="ae_remove_image_button button">' . __('Remove image', 'app-expert') . '</button>
                </td>
            </tr>';
        }

        /**
         * Thumbnail column added to category admin.
         *
         * @access public
         * @param mixed $columns
         * @return void
         */
        public function AppExpertTaxonomyColumns( $columns ) {
            $new_columns = array();
            $new_columns['cb'] = $columns['cb'];
            $new_columns['thumb'] = __('Image', 'app-expert');

            unset( $columns['cb'] );

            return array_merge( $new_columns, $columns );
        }

        /**
         * Thumbnail column value added to category admin.
         *
         * @access public
         * @param mixed $columns
         * @param mixed $column
         * @param mixed $id
         * @return void
         */
        public function AppExpertTaxonomyColumn( $columns, $column, $id ) {
            if ( $column == 'thumb' )
                $columns = '<span><img src="' . $this->AppExpertTaxonomyImageUrl($id, 'thumbnail', TRUE) . '" alt="' . __('Thumbnail', 'app-expert') . '" class="wp-post-image" /></span>';

            return $columns;
        }

        public function AppExpertQuickEditCustomBox($column_name, $screen, $name) {
            if ($column_name == 'thumb') 
                echo '<fieldset>
                <div class="thumb inline-edit-col">
                    <label>
                        <span class="title"><img src="" alt="Thumbnail"/></span>
                        <span class="input-text-wrap"><input type="text" name="aeci_taxonomy_image" value="" class="tax_list" /></span>
                        <span class="input-text-wrap">
                            <button class="ae_upload_image_button button">' . __('Upload/Add image', 'app-expert') . '</button>
                            <button class="ae_remove_image_button button">' . __('Remove image', 'app-expert') . '</button>
                        </span>
                    </label>
                </div>
            </fieldset>';
        }

        public function AppExpertSaveTaxonomyImage($term_id) {
            if(isset($_POST['aeci_taxonomy_image'])) {
                update_option('ae_taxonomy_image'.$term_id, sanitize_text_field($_POST['aeci_taxonomy_image']), false);
            }
        }

        // get attachment ID by image url
        public function AppExpertGetAttachmentIdByUrl($image_src) {
            global $wpdb;
            $query = $wpdb->prepare("SELECT ID FROM $wpdb->posts WHERE guid = %s", $image_src);
            $id = $wpdb->get_var($query);
            return (!empty($id)) ? $id : NULL;
        }

        // get taxonomy image url for the given term_id (Place holder image by default)
        public function AppExpertTaxonomyImageUrl($term_id = NULL, $size = 'full', $return_placeholder = FALSE) {
            if (!$term_id) {
                if (is_category())
                    $term_id = get_query_var('cat');
                elseif (is_tag())
                    $term_id = get_query_var('tag_id');
                elseif (is_tax()) {
                    $current_term = get_term_by('slug', get_query_var('term'), get_query_var('taxonomy'));
                    $term_id = $current_term->term_id;
                }
            }

            $taxonomy_image_url = get_option('ae_taxonomy_image'.$term_id);
            if(!empty($taxonomy_image_url)) {
                $attachment_id = $this->AppExpertGetAttachmentIdByUrl($taxonomy_image_url);
                if(!empty($attachment_id)) {
                    $taxonomy_image_url = wp_get_attachment_image_src($attachment_id, $size);
                    $taxonomy_image_url = $taxonomy_image_url[0];
                }
            }

            if ($return_placeholder)
                return ($taxonomy_image_url != '') ? $taxonomy_image_url : $this->aeci_placeholder;
            else
                return $taxonomy_image_url;
        }

        // display taxonomy image for the given term_id
        public function AppExpertTaxonomyImage($term_id = NULL, $size = 'full', $attr = NULL, $echo = TRUE) {
            if (!$term_id) {
                if (is_category())
                    $term_id = get_query_var('cat');
                elseif (is_tag())
                    $term_id = get_query_var('tag_id');
                elseif (is_tax()) {
                    $current_term = get_term_by('slug', get_query_var('term'), get_query_var('taxonomy'));
                    $term_id = $current_term->term_id;
                }
            }

            $taxonomy_image_url = get_option('ae_taxonomy_image'.$term_id);
            if(!empty($taxonomy_image_url)) {
                $attachment_id = $this->AppExpertGetAttachmentIdByUrl($taxonomy_image_url);
                if(!empty($attachment_id))
                    $taxonomy_image = wp_get_attachment_image($attachment_id, $size, FALSE, $attr);
                else {
                    $image_attr = '';
                    if(is_array($attr)) {
                        if(!empty($attr['class']))
                            $image_attr .= ' class="'.$attr['class'].'" ';
                        if(!empty($attr['alt']))
                            $image_attr .= ' alt="'.$attr['alt'].'" ';
                        if(!empty($attr['width']))
                            $image_attr .= ' width="'.$attr['width'].'" ';
                        if(!empty($attr['height']))
                            $image_attr .= ' height="'.$attr['height'].'" ';
                        if(!empty($attr['title']))
                            $image_attr .= ' title="'.$attr['title'].'" ';
                    }
                    $taxonomy_image = '<img src="'.$taxonomy_image_url.'" '.$image_attr.'/>';
                }
            }
            else{
                $taxonomy_image = '';
            }

            if ($echo)
                echo $taxonomy_image;
            else
                return $taxonomy_image;
        }
    }
}

if (class_exists('App_Expert_Categories_Images')) {
    $ae_categories_images = new App_Expert_Categories_Images();
    
    function app_expert_taxonomy_image_url($term_id = NULL, $size = 'full', $return_placeholder = FALSE) {
        $aeci = new App_Expert_Categories_Images();
        return $aeci->AppExpertTaxonomyImageUrl($term_id, $size, $return_placeholder);
    }

    function app_expert_taxonomy_image($term_id = NULL, $size = 'full', $attr = NULL, $echo = TRUE) {
        $aeci = new App_Expert_Categories_Images();
        return $aeci->AppExpertTaxonomyImage($term_id, $size, $attr, $echo);
    }
    
    function app_expert_is_taxonomy_image_enabled($taxonomy) {
        $check = false;
        $aeci_options = get_option('aeci_options');

        if (!is_array($aeci_options)){
            $aeci_options = array();
        }

        if (empty($aeci_options['included_taxonomies'])){
            $aeci_options['included_taxonomies'] = array();
        }
        
        if (in_array($taxonomy, $aeci_options['included_taxonomies'])) {
            $check = true;
        }
        
        return $check;
    }
}