<?php
if (!defined('ABSPATH')) {
	exit();
}

if (!class_exists('App_Expert_API_Token')) {
	class App_Expert_API_Token
	{

		const ACCESS_TOKEN_EXPIRATION_IN_DAYS = 7;
		const REFRESH_TOKEN_EXPIRATION_IN_DAYS = 30;

		private $user;

		private $issued_at;



		public function __construct(WP_User $user)
		{
			$this->issued_at = time();

			$this->user = $user;
		}


		/**
		 * @return array
		 */
		public function get_access_token()
		{

			$args = array(
				'exp' => $this->get_expiration_date(true),
				'data' => array(
					'user' => array(
						'id' => $this->user->data->ID,
						'user_login' => $this->user->data->user_login,
						'user_uri' => property_exists($this->user->data, 'user_uri') ? $this->user->data->user_uri : null,
						'first_name' => property_exists($this->user->data, 'first_name') ? $this->user->data->first_name : null,
						'last_name' => property_exists($this->user->data, 'last_name')  ? $this->user->data->last_name : null,
						'user_email' => $this->user->data->user_email,
						'user_nicename' => $this->user->data->user_nicename,
						'user_display_name' => $this->user->data->display_name,
					)
				)
			);

			return array_merge($args, $this->get_static_data());
		}

		/**
		 * @return array
		 */
		public function get_refresh_token()
		{

			$args = array(
				'exp' => $this->get_expiration_date(false),
				'random' => rand()

			);
			return array_merge($args, $this->get_static_data());
		}

		/**
		 * @return array
		 */
		private function get_static_data()
		{
			return array(
				'iss' => get_bloginfo('name'),
				'iat' => $this->issued_at,
			);
		}

		/**
		 * @param bool $is_access_token
		 *
		 * @return float|int
		 */
		private function get_expiration_date(bool $is_access_token)
		{
			$days = $is_access_token ? self::ACCESS_TOKEN_EXPIRATION_IN_DAYS : self::REFRESH_TOKEN_EXPIRATION_IN_DAYS;

			return $this->issued_at + (DAY_IN_SECONDS * $days);
		}
	}
}
