<?php
if (!defined('ABSPATH')) {
	exit();
}

if (!class_exists('App_Expert_Response')) {
	class App_Expert_Response
	{

		private static $response_data;

		public function __construct()
		{
			add_filter('rest_post_dispatch', array(self::class, 'rest_filter_response_fields'), 1, 3);

			add_filter('rest_pre_echo_response', array(self::class, 'rest_after_filter_response_fields'), 1, 3);
		}


		/**
		 * @param WP_REST_Response $response
		 * @param string $code
		 * @param string $message
		 *
		 * @return array
		 */
		public static function get_api_list_success_response(WP_REST_Response $response, string  $code, string  $message)
		{
			$headers = $response->get_headers();
			return array(
				'code' => $code,
				'message' => $message,
				'data' => array(
					'status' => 200,
					'items' => $response->get_data(),
					'current_page' => isset($_GET['page']) ? intval($_GET['page']) : 1,
					'total_count' => isset($headers['X-WP-Total']) ? $headers['X-WP-Total'] : 0,
					'total_pages' => isset($headers['X-WP-TotalPages']) ? $headers['X-WP-TotalPages'] : 0,
					'has_next' => self::is_link_next_or_prev(true, $headers),
					'has_prev' => self::is_link_next_or_prev(false, $headers)
				)
			);
		}

		/**
		 * @param WP_REST_Response $response
		 * @param string $code
		 * @param string $message
		 *
		 * @return array
		 */
		public static function get_api_single_success_response(WP_REST_Response $response, string  $code, string  $message)
		{
			return array(
				'code' => $code,
				'message' => $message,
				'data' =>
				array_merge(
					array('status' => 200),
					$response->get_data()
				)

			);
		}

		/**
		 * Get success response with custom array data content
		 * 
		 * @param array $data
		 * @param string $code
		 * @param string $message
		 *
		 * @return array
		 */
		public static function get_api_custom_success_response(array $data, string  $code, string  $message)
		{
			return array(
				'code' => $code,
				'message' => $message,
				'data' => array_merge(
					array('status' => 200),
					$data
				)

			);
		}

		/**
		 * @return array
		 */
		private static function get_user_wp_fields()
		{
			return array(
				'id' => 'id',
				'user_email' => 'email',
				'first_name' => 'first_name',
				'last_name' => 'last_name',
				'avatar_urls' => 'image'
			);
		}

		public static function prepare_user_data_for_response(WP_User $user)
		{
			$fields = App_Expert_Response::get_user_wp_fields();

			$data = array();
			if (isset($fields['id'])) {
				$data[$fields['id']] = $user->ID;
			}

			if (isset($fields['user_email'])) {
				$data[$fields['user_email']] = $user->user_email;
			}

			if (isset($fields['first_name'])) {
				$data[$fields['first_name']] = $user->first_name;
			}

			if (isset($fields['last_name'])) {
				$data[$fields['last_name']] = $user->last_name;
			}

			if (isset($fields['avatar_urls'])) {
				$data[$fields['avatar_urls']] = array(
					'small' => get_avatar_url($user, array('size' => App_Expert_Users_Controller::USER_IMAGE_SMALL)),
					'medium' => get_avatar_url($user, array('size' => App_Expert_Users_Controller::USER_IMAGE_MEDIUM)),
					'large' =>  get_avatar_url($user, array('size' => App_Expert_Users_Controller::USER_IMAGE_LARGE)),
				);
			}

			return $data;
		}

		/**
		 * @param bool $search_for_next
		 * @param array $headers
		 *
		 * @return bool
		 */
		public static function is_link_next_or_prev(bool $search_for_next, array  $headers)
		{
			if (!isset($headers['Link']) || empty($headers['Link']))
				return false;

			$link = $headers['Link'];
			if ($search_for_next)
				return strpos($link, 'next') !== false;

			return strpos($link, 'prev') !== false;
		}

		/**
		 * @param WP_REST_Response $response
		 * @param WP_REST_Server $server
		 * @param WP_REST_Request $request
		 *
		 * @return WP_REST_Response
		 */
		public static function rest_filter_response_fields(WP_REST_Response  $response, WP_REST_Server $server, WP_REST_Request $request)
		{
			if (!self::isAppExpertRoute($request->get_route()))
				return $response;

			self::$response_data = $response->get_data();

			if (!isset(self::$response_data['data']['items']))
				return $response;

			$response->set_data(self::$response_data['data']['items']);

			return $response;
		}

		/**
		 * @param string $request_uri
		 *
		 * @return bool
		 */
		private static function isAppExpertRoute(string $request_uri)
		{
			$valid_api_uri = strpos($request_uri, APP_EXPERT_API_NAMESPACE);

			return $valid_api_uri !== false;
		}

		public static function rest_after_filter_response_fields(?array $response, WP_REST_Server $server, WP_REST_Request $request)
		{
			if (!self::isAppExpertRoute($request->get_route()))
				return $response;

			if (!isset(self::$response_data['data']['items'])) {
				if (self::is_param_validation_response($response)) {
					$response = self::fix_param_validation_response_translations($response, $request);
				}
				return $response;
			}

			self::$response_data['data']['items'] = $response;



			return self::$response_data;
		}


		public static function is_param_validation_response($response)
		{
			return (isset($response['code']) && $response['code'] ==  "rest_invalid_param"
				&& isset($response['data']) && isset($response['data']['params']));
		}


		/**
		 * Fix translation of validation errors in response that was translated in 
		 * an early call before translation functionnality is ready
		 * @param $response
		 * @param $request
		 * 
		 * @return $response
		 */
		public static function fix_param_validation_response_translations($response, $request)
		{
			$lang = $request->get_param("wpml_language");
			$lang = $lang ? $lang : get_locale();
			$is_WPML_enabled = App_Expert_Settings_Controller::is_WPML_enabled();

			foreach ($response['data']['params'] as $key => $param) {
				$string = $response['data']['params'][$key];
				$response['data']['params'][$key] =
					$is_WPML_enabled ?
					apply_filters('wpml_translate_single_string', $string, 'app-expert', $string, $lang)
					: __($string, 'app-expert');
			}

			return $response;
		}
	}
}
new App_Expert_Response();
