<?php
if (!defined('ABSPATH')) {
    exit();
}

if (!class_exists('App_Expert_WPML_Controller')) {
       
    /**
     * Add WPML APIs
     */
    class App_Expert_WPML_Controller {
        public function __construct() {
            $this->rest_base = '/languages';
            $this->namespace = APP_EXPERT_API_NAMESPACE;
        }
        
        public function register_routes() {
            register_rest_route(
                $this->namespace,
                '/' . $this->rest_base . '/active',
                array(
                    'methods'  => WP_REST_Server::READABLE,
                    'callback' => array( $this, 'get_active_languages' ),
                )
            );
            
            register_rest_route(
                $this->namespace,
                '/' . $this->rest_base . '/translation',
                array(
                    'methods'  => WP_REST_Server::READABLE,
                    'callback' => array( $this, 'get_object_translation_id' ),
                )
            );
        }
        
        public function get_active_languages($request) {
            if (in_array('sitepress-multilingual-cms/sitepress.php', apply_filters('active_plugins', get_option('active_plugins')))) {
                $langs = apply_filters('wpml_active_languages', NULL, 'orderby=id&order=asc');

                return App_Expert_Response::get_api_custom_success_response(array('languages' => $langs), 'app_expert_active_languages', __('Active Languages were returned successfully', 'app-expert'));
            }else{
                $langs = array();
                $locale = get_locale();
                require_once( ABSPATH . 'wp-admin/includes/translation-install.php' );
                $translations = wp_get_available_translations();
                if($locale === 'en_US'){
                    $langs['en'] = array(
                        'code'=> 'en',
                        'id'=> '',
                        'native_name'=> 'English',
                        'major'=> '',
                        'active'=> '',
                        'default_locale'=> 'en_US',
                        'encode_url'=> '',
                        'tag'=> '',
                        'translated_name'=> 'English',
                        'url'=> '',
                        'country_flag_url'=> '',
                        'language_code'=> ''
                    );
                }elseif(isset($translations[$locale])){
                    $translation = $translations[$locale];
                    $langs[current( $translation['iso'] )] = array(
                        'code'=> current( $translation['iso'] ),
                        'id'=> '',
                        'native_name'=> $translation['native_name'],
                        'major'=> '',
                        'active'=> '',
                        'default_locale'=> $translation['language'],
                        'encode_url'=> '',
                        'tag'=> '',
                        'translated_name'=> $translation['english_name'],
                        'url'=> '',
                        'country_flag_url'=> '',
                        'language_code'=> ''
                    );
                }else{
                    $langs['en'] = array(
                        'code'=> 'en',
                        'id'=> '',
                        'native_name'=> 'English',
                        'major'=> '',
                        'active'=> '',
                        'default_locale'=> 'en_US',
                        'encode_url'=> '',
                        'tag'=> '',
                        'translated_name'=> 'English',
                        'url'=> '',
                        'country_flag_url'=> '',
                        'language_code'=> ''
                    );
                }
                return App_Expert_Response::get_api_custom_success_response(array('languages' => $langs), 'app_expert_active_languages', __('Active Languages were returned successfully', 'app-expert'));
            }
        }
        
        public function get_object_translation_id($request) {
            $missing = array();
            if(isset($request['org_id']) && $request['org_id']){
                $org_id = $request['org_id'];
            }else{
                $missing[] = '"org_id"';
            }
            if (in_array('sitepress-multilingual-cms/sitepress.php', apply_filters('active_plugins', get_option('active_plugins'))) ) {
                
                if(isset($request['type']) && $request['type']){
                    $type = $request['type'];
                }else{
                    $missing[] = '"type"';
                }
                if(isset($request['lang']) && $request['lang']){
                    $lang = $request['lang'];
                }else{
                    $missing[] = '"lang"';
                }
                $is_org = false;
                if(isset($request['is_org'])){
                    $is_org = $request['is_org'];
                }

                if(count($missing) == 0){
                    $trans_id = apply_filters( 'wpml_object_id', $org_id, $type, $is_org, $lang );

                    if($trans_id){
                        return App_Expert_Response::get_api_custom_success_response(array('trans_id' => $trans_id), 'app_expert_object_translation_id', __('Translation id was returned successfully', 'app-expert'));
                    }else{
                        return new WP_Error(
                            'app_expert_not_found',
                            __('No translation found', 'app-expert'),
                            array(
                                'status' => 404
                            )
                        );
                    }
                }else{
                    return new WP_Error(
                        'app_expert_missing_param',
                        implode(' ,', $missing). ' missing',
                        array(
                            'status' => 404
                        )
                    );
                }
            }else{
                if(count($missing) == 0){
                    return App_Expert_Response::get_api_custom_success_response(array('trans_id' => $org_id), 'app_expert_object_translation_id', __('Translation id was returned successfully', 'app-expert'));
                }else{
                    return new WP_Error(
                        'app_expert_missing_param',
                        implode(' ,', $missing). ' missing',
                        array(
                            'status' => 404
                        )
                    );
                }
            }
        }
    }

    $app_expert_wpml_controller = new App_Expert_WPML_Controller();
    $app_expert_wpml_controller->register_routes();
}
